<CsoundSynthesizer>

<CsOptions>
-odac
</CsOptions>

<CsInstruments>

;;;; *************** Drums and Different Canons *************
;;;;
;;;; Orchestra file for prelude
;;;;

sr      =       44100
kr      =       441
ksmps   =       100
nchnls  =       2

gasnd   init    0

instr 4,5
;Start  dur     baseamp ampinc  Noise/cps       loc       Timbre
;p2     p3      p4      p5      p6              p7        p8
; The only difference between the two drums here is the base frequency
        if p1==5 igoto high
        ;; Instrument 4
                i2 = cpspch(p8) ; 11; 12.5
                igoto common
high:   ;; Instrument 5
                i2 = cpspch(20)
common:
        i1 = 1/p3               ; once per duration - for envelopes
        i3 = (p4+p5)            ; these three assignments balance the three
        i4 = (p4+p5)/3          ; branches of the drum instrument
        i5 = (p4+p5)/2.1        ;

                                ; branch 1 - NOISE
a1      oscili  i3,i1,2         ; generate steep exponential envelope
a1      randi   a1,p6/2         ; generate band of noise with freq. given by p5
a1      oscili  a1,500,4        ; use noise band for amp input - ring mod.

                                ; branch 2 - INHARM
a2      oscili  i4,i1,2         ; steep envelope with lower amplitude than a1
a2      oscili  a2,i2*.1,3      ; generate inharmonic partials - 1,1.6,2.2,2.3

                                ; branch 3 - FUND
a3      oscili  i5,i1,1         ; decay of f1 is less steep than f2
a3      oscili  a3,i2,4         ; generates fundamental tone

                                ; global envelope to prevent clicking
a4      linseg  1,p3-.05,1,.05,0,.01,0
a5  =   a4*(a1+a2+a3)
a6  =   a5*p7
a7  =   a5*(1-p7)
        outs a6, a7
        ;; Delay these signals to provide a little of the effect
a8      delay1 a7*p7
a9      delay1 a7*(1-p7)
        outs a8, a9
gasnd   =       gasnd + a5 * 0.25
endin

instr 6
;; The parameter i2 seems to control basic sound type
;;              15.2 has a metalic ring 15.1 is more wooden
;;              15.0 is rather like 15.1
        i2 = cpspch(15.1+p5/1000)
        i1 = 1/p3               ; once per duration - for envelopes
        i3 = p4                 ; these three assignments balance the three
        i4 = p4                 ; branches of the drum instrument
        i5 = p4/6.25
                                ; branch 1 - NOISE
a1      oscili  i3,i1,2         ; generate steep exponential envelope
a1      randi   a1,p5/2         ; generate band of noise with freq. given by p5
a1      oscili  a1,500,4        ; use noise band for amp input - ring mod.

                                ; branch 2 - INHARM
a2      oscili  i4,i1,2         ; steep envelope with lower amplitude than a1
a2      oscili  a2,i2*.2,3      ; generate inharmonic partials - 1,1.6,2.2,2.3

                                ; branch 3 - FUND
a3      oscili  i5,i1,1         ; decay of f1 is less steep than f2
a3      oscili  a3,i2,4         ; generates fundamental tone

                                ; global envelope to prevent clicking
a4      linseg  1,p3-.05,1,.05,0,.01,0
a5  =   a4*(a1+a2+a3)
a6  =   a5*p6
a7  =   a5*(1-p6)
        outs a6, a7
        ;; Delay these signals to provide a little of the effect
a8      delay1 a7*p6
a9      delay1 a7*(1-p6)
        outs a8, a9
gasnd   =       gasnd + a5 * 0.1
endin

instr 10       ;simple marimba
               ;p4=pch p5=amp p6=bias

i5	=	p5+800
i1      =       cpsoct(p4)
i2	=	log(i1)/10.0 - p6
k1      expseg  .0001,.03,i5,p3-.03,.001      ;env
k25     linseg  1,.03,1,p3-.03,3
k1      =       k25*k1
k10     linseg  2.25,.03,3,p3-.03,2     ;power to partials
a1      gbuzz   k1,i1,k10,0,35,4
a2      reson   a1,500,50,1     ;filt
a3      reson   a2,1500,100,1   ;filt
a4      reson   a3,2500,150,1   ;filt
a5      reson   a4,3500,150,1   ;filt
a6      balance a5,a1
i6	=	p6
ga7	=	a6*i2
ga8	=	a6*(1-i2)
;;	display a6, 0.25
        outs    ga7,ga8
gasnd	=	gasnd + a6 * 0.1
;;	out	a6
        endin

instr   99
asig    reverb  gasnd, p4
        outs    asig, asig
gasnd   =       0
endin



</CsInstruments>

<CsScore>

;;;; Prelude for Drums and Different Canons
;; Basically an attempt at a short (~ 10sec) fanfare with the main
;; instrument types introduced.  It is structurally a canon between 
;; drums (voice 1) and marimbas (voice 2).  No ending shimmer, and some
;; echo

; amp envelopes
f1 0 1024 5 1 1024 .004
f2 0 1024 5 1 1024 .00012

; waveforms
f3 0 1024 9 10 1 0 16 1.5 0 22 2 0 23 1.5 0
f4 0 1024 9 1 1 0

t0 750

;i4/5	Start	dur	baseamp	ampinc	Noise		loc		Timbre
;i6	Start	dur	amp	Noise		loc
;i10	Start	dur	Pitch	AmpInc		Bias

;; The echo/reverb component
i99	1	62	1
i99	62	50	5

i4	1	10	200	10800	770		1.00		6
i4	1	10	>	0	1010		<		>
i4	4	10	>	0	674		<		>
i4	4	10	>	5000	1028		<		>
i4	7	10	>	0	592		<		>
i4	7	10	>	0	903		<		>
i4	11	10	>	6800	853		<		>
i4	12	10	>	0	1009		<		>
i4	14	10	>	0	701		<		>
i4	15	10	>	0	1054		<		>
i4	17	10	>	5000	519		<		>
i4	18	10	>	0	727		<		>
i4	20	10	>	10800	924		<		>
i4	21	10	>	0	859		<		>
i4	22	10	>	0	1010		<		>
i4	25	10	>	5000	699		<		>
i4	25	10	>	0	1053		<		>
i4	29	10	>	0	521		<		>
i4	32	10	>	6800	734		<		>
i4	32	10	>	0	928		<		>
i4	33	10	>	0	854		<		>
i4	34	10	>	0	1016		<		>
i4	37	10	>	5000	681		<		>
i4	37	10	>	0	1038		<		>
i4	40	10	>	10800	564		<		>
i4	42	10	>	0	844		<		>
i4	42	10	>	0	916		<		>
i4	43	10	>	0	907		<		>
i4	44	30	>	5000	944		<		>
i4	46	28	>	0	875		<		>
i4	47	27	>	0	999		<		>
i4	49	25	>	6800	737		<		>
i4	49	25	>	0	1072		<		>
i4	52	22	1000	0	468		0.00		10

;; The same material, 10 time units later
i10	11	15	7.70	10800		0.20
i10	11	15	10.10	0		<	
i10	14	15	6.74	0		<	
i10	14	15	10.28	5000		<	
i10	17	15	5.92	0		<	
i10	17	15	9.03	0		<	
i10	21	15	8.53	6800		<	
i10	22	15	10.09	0		<	
i10	24	15	7.01	0		<	
i10	25	15	10.54	0		<	
i10	27	15	5.19	5000		<	
i10	28	15	7.27	0		<	
i10	30	15	9.24	10800		<	
i10	31	15	8.59	0		<	
i10	32	15	10.10	0		<	
i10	35	15	6.99	5000		<	
i10	35	15	10.53	0		<	
i10	39	15	5.21	0		<	
i10	42	15	7.34	6800		<	
i10	42	15	9.28	0		<	
i10	43	15	8.54	0		<	
i10	44	15	10.16	0		<	
i10	47	15	6.81	5000		<	
i10	47	15	10.38	0		<	
i10	50	15	5.64	10800		<	
i10	52	15	8.44	0		<	
i10	52	15	9.16	0		<	
i10	53	15	9.07	0		<	
i10	54	15	9.44	5000		<	
i10	56	15	8.75	0		<	
i10	57	15	9.99	0		<	
i10	59	15	7.37	6800		<	
i10	59	15	10.72	0		<	
i10	62	12	4.68	0		0.00	
;;i6	57	20	3000	956		0.50
e


</CsScore>

</CsoundSynthesizer>

